import io
import json
from kafka import KafkaConsumer
from kafka import TopicPartition
from IPython.display import display
import datetime
import time

servers = ['localhost:9092']
def deserializer(v):
	return json.loads(v.decode('utf-8'))

topic = "weather"
verbose= "xyes"

# Some microsecond increments
minute_ms=60000
hour_ms=60*minute_ms
day_ms=24*hour_ms

# Determine the epoch time for date (Year,Month,Day)
start_epoch = int(datetime.datetime(2023,3,19,0, 0).strftime('%s'))*1000

# Set the finish time to start time plus number of ms
finish_epoch=int(start_epoch+(18*hour_ms)+(30*minute_ms))

# print out readable start and finish times
start_date_time = time.strftime('%Y-%m-%d %H:%M:%S', time.localtime(start_epoch/1000))
finish_date_time = time.strftime('%Y-%m-%d %H:%M:%S', time.localtime(finish_epoch/1000))
print("Range Start: %s" % start_date_time)
print("Range Finish: %s" % finish_date_time)

# Select and read a specific time 
# set up consumer and add 5 second time out 

consumer = KafkaConsumer(bootstrap_servers=servers, consumer_timeout_ms=5000,
                         value_deserializer=deserializer)

# For real installations, there will be multiple partions
# for a topic. Cycle though all partions
topic_partitions = consumer.partitions_for_topic(topic)

for part in topic_partitions:
	print("Checking partition: %d" % part)

	partition = TopicPartition('weather', part)
	consumer.assign([partition])
	# NOTE from author: offsets_for_times will return the first offset, which timestamp 
	# is greater or equal to the requested timestamp. All timestamps are in milliseconds.
	# If you get None it means that Broker does not have any messages larger than 
	# the provided timestamp (either because topic is empty, offsets were removed 
	# or no messages with timestamp larger were yet produced).
	start  = consumer.offsets_for_times({partition:start_epoch})
	finish  = consumer.offsets_for_times({partition:finish_epoch})
	consumer.seek(partition, start[partition].offset) 
	
	for message in consumer:
		if finish[partition] is not None:
			if message.offset >= finish[partition].offset:
				break
		if message.key is not None:
			key=message.key.decode("utf-8")
		else:
			key='NO KEY'
		time=datetime.datetime.fromtimestamp(message.timestamp/1000.0)
		# use message.value to print the full contents of the message
		print("  Partition: %s Message Offset %d Zipcode %s" % (part, message.offset,key))
		print("   Time: %s (%s)" % (time, message.timestamp))

exit()

